Crate sp1_build

Crate sp1_build 

Macros

include_elf
Returns the raw ELF bytes by the zkVM program target name.

Structs

BuildArgs
Compile an SP1 program.

Enums

Elf
A type that represents an ELF binary, always cheap to clone.
WarningLevel
Controls the warning message verbosity in the build process.

Constants

DEFAULT_TARGET
TOOLCHAIN_NAME

Functions

build_program
Builds the program if the program at the specified path, or one of its dependencies, changes.
build_program_with_args
Builds the program with the given arguments if the program at path, or one of its dependencies, changes.
execute_build_program
Build a program with the specified BuildArgs. The program_dir is specified as an argument when the program is built via build_program.
generate_elf_paths
Collects the list of targets that would be built and their output ELF file paths.