execute_build_program

Function execute_build_program 

pub fn execute_build_program(
    args: &BuildArgs,
    program_dir: Option<PathBuf>,
) -> Result<Vec<(String, Utf8PathBuf)>>
Build a program with the specified BuildArgs. The program_dir is specified as an argument when the program is built via build_program.

Arguments

  • args - A reference to a BuildArgs struct that holds various arguments used for building the program.
  • program_dir - An optional PathBuf specifying the directory of the program to be built.

Returns

  • Result<Vec<(String, Utf8PathBuf)>> - A list of mapping from bin target names to the paths to the built program as a Utf8PathBuf on success, or an error on failure.