pub struct BuildArgs {Show 14 fields
pub docker: bool,
pub tag: String,
pub features: Vec<String>,
pub rustflags: Vec<String>,
pub no_default_features: bool,
pub ignore_rust_version: bool,
pub locked: bool,
pub packages: Vec<String>,
pub binaries: Vec<String>,
pub elf_name: Option<String>,
pub output_directory: Option<String>,
pub workspace_directory: Option<String>,
pub warning_level: WarningLevel,
pub no_docker_cache: bool,
}Expand description
Compile an SP1 program.
Additional arguments are useful for configuring the build process, including options for using Docker, specifying binary and ELF names, ignoring Rust version checks, and enabling specific features.
Fields
docker: booltag: Stringfeatures: Vec<String>rustflags: Vec<String>no_default_features: boolignore_rust_version: boollocked: boolpackages: Vec<String>binaries: Vec<String>elf_name: Option<String>output_directory: Option<String>workspace_directory: Option<String>warning_level: WarningLevelno_docker_cache: boolTrait Implementations
Sourceimpl Args for BuildArgs
impl Args for BuildArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for BuildArgs
impl CommandFactory for BuildArgs
Sourceimpl FromArgMatches for BuildArgs
impl FromArgMatches for BuildArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for BuildArgs
impl Parser for BuildArgs
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)