pub fn execute_build_program(
args: &BuildArgs,
program_dir: Option<PathBuf>,
) -> Result<Vec<(String, Utf8PathBuf)>>Expand description
Build a program with the specified BuildArgs. The program_dir is specified as an argument
when the program is built via build_program.
Arguments
args- A reference to aBuildArgsstruct that holds various arguments used for building the program.program_dir- An optionalPathBufspecifying the directory of the program to be built.
Returns
Result<Vec<(String, Utf8PathBuf)>>- A list of mapping from bin target names to the paths to the built program as aUtf8PathBufon success, or an error on failure.